from setuptools import setup

setup(
    name='thisisjustapackage',
    version='0.0.6',
    description='this is just a package',
    author='thisisjust',
    author_email='this@is.just',
    packages=['package'],
    install_requires=['urllib3 == 1.26.9']
)